<template>
  <a-card
    title='设备变动'
    :bordered='false'
  >
    <div class='table-page-search-wrapper'>
      <a-form
        layout='inline'
        @keyup.enter.native='searchQuery'
      >
        <a-row :gutter='24'>
          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <a-form-item label='单据号'>
              <a-input
                placeholder='请输入单据号'
                v-model='queryParam.num'
              ></a-input>
            </a-form-item>
          </a-col>

          <a-col :xl='6' :lg='7' :md='8' :sm='24'>
            <a-form-item label='审批状态'>
              <j-dict-select-tag placeholder='请选择审批状态' v-model='queryParam.auditStatus' dictCode='audit_status' />
            </a-form-item>
          </a-col>
          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <span
              style='float: left;overflow: hidden;'
              class='table-page-search-submitButtons'
            >
              <a-button
                type='primary'
                @click='searchQuery'
                icon='search'
              >查询</a-button>
              <a-button
                type='primary'
                @click='searchReset'
                icon='reload'
                style='margin-left: 8px'
              >重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>

    <div class='table-operator'>
      <a-button
        style='margin-top: 15px'
        @click='handleAdd'
        type='primary'
        v-has="'equipmentChange:add'"
        icon='plus'
      >新增
      </a-button>
      <a-button
        v-if="selectedRowKeys.length > 0  && (selectionRows[0].auditStatus==='notSubmitted' || selectionRows[0].auditStatus==='Rejected')"
        @click='handleSubmit' type='primary' icon='check' v-has="'equipmentChange:submitAndCancel'">提交
      </a-button>
      <a-button v-if="selectedRowKeys.length > 0  && selectionRows[0].auditStatus === 'pendingApproval'"
                @click='handleRevocation' type='primary' icon='rollback'>撤回
      </a-button>
    </div>

    <!-- table区域-begin -->
    <div>
      <div
        class='ant-alert ant-alert-info'
        style='margin-bottom: 16px;'
      >
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a
        style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a
          style='margin-left: 24px'
          @click='onClearSelected'
        >清空</a>
      </div>

      <a-table
        ref='table'
        size='middle'
        bordered
        rowKey='id'
        :scroll="{ x: 'calc(1400px + 50%)', y: 900 }"
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange,type:'radio'}"
        :customRow='clickThenSelect'
        @change='handleTableChange'
      >

<!--       <span
         slot='action'
         slot-scope='text, record'
       >
          <a v-if="record.auditStatus === 'notSubmitted' || record.auditStatus === 'Rejected'" @click='handleEdit(record)'>编辑</a>
          <a v-if="record.auditStatus === 'pendingApproval'" @click='handleApprove(record)'>审批</a>

          <a-divider v-if="record.auditStatus === 'notSubmitted' || record.auditStatus === 'Rejected'" type='vertical' />
        <a-dropdown v-if="record.auditStatus === 'notSubmitted' || record.auditStatus === 'Rejected'">
                        <a class='ant-dropdown-link'>更多 <a-icon type='down' /></a>
                        <a-menu slot='overlay'>
                            <a-menu-item>
                                <a-popconfirm title='确定删除吗?'
                                              @confirm='() => handleDelete(record.id)'>
                                    <a>删除</a>
                                </a-popconfirm>
                            </a-menu-item>

                        </a-menu>
                    </a-dropdown>
        </span>-->
        <span
          slot='action'
          slot-scope='text, record'
        >
          <a v-if="record.auditStatus === 'notSubmitted' || record.auditStatus === 'Rejected'" @click='handleEdit(record)' v-has="'equipmentChange:edit'">编辑</a>
          <a v-if="record.auditStatus === 'pendingApproval'" @click='handleApprove(record)'>审批</a>

          <a-divider
            v-if="record.auditStatus === 'notSubmitted' || record.auditStatus === 'Rejected' || record.auditStatus === 'pendingApproval'"
            type='vertical'
          />
        <a-dropdown>
                        <a class='ant-dropdown-link'>更多 <a-icon type='down' /></a>
                        <a-menu slot='overlay'>
                           <a-menu-item>
                            <a @click='handleDetail(record)'>详情</a>
                            </a-menu-item>
                            <a-menu-item v-if="record.auditStatus === 'notSubmitted'||record.auditStatus === 'Rejected'" v-has="'equipmentChange:delete'">
                                <a-popconfirm title='确定删除吗?'
                                              @confirm='() => handleDelete(record.id)'>
                                    <a>删除</a>
                                </a-popconfirm>
                            </a-menu-item>

                        </a-menu>
                    </a-dropdown>
        </span>
      </a-table>
      <a-tabs defaultActiveKey='1'>
        <a-tab-pane
          tab='设备调出明细'
          key='1'
        >
          <div
            class='table-operator'
            style='margin:-16px'
          >
            <equipment-change-detail :equipmentChangeId='equipmentChangeId'/>
          </div>
        </a-tab-pane>

      </a-tabs>
    </div>

    <equipment-change-detail-modal
      ref='modalForm'
      @ok='modalFormOk'
    ></equipment-change-detail-modal>
    <approvel-modal ref='approvalModalForm' @cancel='approvalModalFormOk' @ok='approvalModalFormOk'></approvel-modal>
  </a-card>
</template>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'

import { getAction, putAction } from '@/api/manage'
import EquipmentChangeDetail from './modules/equipmentChange/EquipmentChangeDetail'
import EquipmentChangeDetailModal from './modules/equipmentChange/EquipmentChangeDetailModal'
import ApprovelModal from '@views/common/ApprovelModal'
import '@/assets/less/TableExpand.less'
import { filterObj } from '@/utils/util'

export default {
  name: 'EquipmentTransferList',
  mixins: [JeecgListMixin],
  components: {
    EquipmentChangeDetail,
    EquipmentChangeDetailModal,
    ApprovelModal
  },
  data() {
    return {
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '审批状态',
          align: 'center',
          dataIndex: 'audit_status'

        },
        {
          title: '单据号',
          align: 'center',
          dataIndex: 'num'
        },
        {
          title: '创建人',
          align: 'center',
          dataIndex: 'createBy'
        },
        {
          title: '创建日期',
          align: 'center',
          dataIndex: 'createTime'
        },
        {
          title: '更新人',
          align: 'center',
          dataIndex: 'updateBy'
        },
        {
          title: '更新日期',
          align: 'center',
          dataIndex: 'updateTime'
        },
        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          scopedSlots: { customRender: 'action' },
          width: 200
        }
      ],
      url: {
        list: '/eam/equipmentChange/getEquipmentChangeList',
        delete: '/eam/equipmentChange/delete',
        deleteBatch: '/eam/equipmentChange/deleteBatch',
        edit: '/eam/equipmentChange/edit',
        submit: 'eam/equipmentChange/submit',
        revocation: 'eam/equipmentChange/revocation',
        reject: 'eam/equipmentChange/reject',
        approval: 'eam/equipmentChange/approval'
      },
      version: '1.0',
      dictOptions: {},
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 5,
        transferType: 'add',
        pageSizeOptions: ['5', '10', '50'],
        showTotal: (total, range) => {
          return range[0] + '-' + range[1] + ' 共' + total + '条'
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      equipmentChangeId: ''
    }
  },
  methods: {

    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(','), [record])
          }
        }
      }
    },
    onClearSelected() {
      this.selectedRowKeys = []
      this.selectionRows = []
      this.equipmentChangeId = ''
    },
    onSelectChange(selectedRowKeys, selectionRows) {
      if (selectedRowKeys.length == 1) {
        // this.selectedTemplateId = selectedRowKeys[0]
        this.equipmentChangeId = selectionRows[0]['id']
      } else {

        this.equipmentChangeId = ''
      }
      this.selectedRowKeys = selectedRowKeys
      this.selectionRows = selectionRows
    },
    handleApprove: function(record) {
      let reject, approval
      reject = this.url.reject
      approval = this.url.approval
      this.$refs.approvalModalForm.showModals(record, reject, approval)
      this.$refs.approvalModalForm.title = '审批'
      this.$refs.approvalModalForm.disableSubmit = false

    },
    approvalModalFormOk() {
      // 通过/驳回时，重载列表
      this.loadData()
      //清空列表选中
      this.onClearSelected()
    },
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      this.onClearSelected()
      var params = this.getQueryParams()//查询条件
      this.loading = true
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records
          this.ipagination.total = res.result.total
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false
      })
    },

    getQueryParams() {
      //获取查询条件
      let sqp = {}
      if (this.superQueryParams) {
        sqp['superQueryParams'] = encodeURI(this.superQueryParams)
        sqp['superQueryMatchType'] = this.superQueryMatchType
      }
      var param = Object.assign(sqp, this.queryParam, this.isorter, this.filters)
      param.field = this.getQueryField()
      param.pageNo = this.ipagination.current
      param.pageSize = this.ipagination.pageSize
      param.changeMethod = 'change'
      return filterObj(param)
    },
    getQueryField() {
      //TODO 字段权限控制
      var str = 'id,'
      this.columns.forEach(function(value) {
        str += ',' + value.dataIndex
      })
      return str
    },

    searchReset() {
      this.equipmentChangeId = ''
      this.queryParam = {}
      this.loadData(1)
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';

.table-operator .ant-btn {
  margin: 10px 8px 8px 10px;
}
</style>